<?php

namespace App\Livewire\Admin;

use App\Models\Shop;
use App\Models\User;
use Illuminate\Database\Events\TransactionBeginning;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Attributes\On;
use Livewire\Component;
use Livewire\Attributes\Url;
use Livewire\WithPagination;

class ShopsComponent extends Component
{
    use WithPagination;
    use LivewireAlert;
    #[Url]
    public $search = '';
    public $isModalOpen = false;
    public $shopItem = null;
    public $shopIdToDelete = null;
    public $editMode = false;
    public $adminName, $adminEmail, $password, $password_confirmation;
    protected $rules = [
        'shopItem.name' => 'required|string|min:3|max:255',
        'shopItem.address' => 'required_if:editMode,false|string|max:255', 
        'shopItem.phone' => 'required_if:editMode,false|string|max:255',
        'adminName' => 'required_if:editMode,false|string|min:3|max:255',
        'adminEmail' => 'required_if:editMode,false|string|unique:users,email',
        'password' => 'required_if:editMode,false|string|min:8|confirmed',
    ];
  
    public function render()
    {
        return view('livewire.admin.shops-component', [
            'items' => Shop::where('name', 'like', '%'.$this->search.'%')->paginate(10),
        ]);
    }
    public function openModal($shopId = null)
    {
        $this->editMode = $shopId ? true : false;
        $this->shopItem = Shop::find($shopId);
        if (!$this->shopItem) {
            $this->shopItem = new Shop();
           
        }
         $this->adminName = '';
            $this->adminEmail = '';
            $this->password = '';
            $this->password_confirmation = '';
        $this->isModalOpen = true;
    }
    public function save()
    {
        
        $this->validate();
        DB::beginTransaction();
        try {
            $this->shopItem->save();
            if($this->editMode == false){
                $user = new User();
                $user->name = $this->adminName;
                $user->email = $this->adminEmail;
                $user->password = Hash::make($this->password);
                $user->role = 'owner';
                $user->shop_id = $this->shopItem->id;
                $user->save();
            }
            $this->isModalOpen = false;
            $this->dispatch('shop-added');
            $this->reset();
            DB::commit();
            $this->alert('success', 'Magasin ajouté avec succès');
        } catch (\Exception $e) {
            DB::rollback();
            $this->alert('error', 'Une erreur est survenue lors de l\'enregistrement');
            return;
        }
    }
    public function delete($shopId)
    {
        $this->shopIdToDelete = $shopId;
        $this->confirm('Voulez-vous vraiment supprimer ce magasin ?', [
            'onConfirmed' => 'confirmed',

        ]);
    }
    #[On('confirmed')]
    public function confirmDelete()
    {
        $shop = Shop::find($this->shopIdToDelete);
        $shop->deleted_by = Auth::user()->id;
        $shop->delete();
        $this->reset('shopIdToDelete');
        $this->alert('success', 'Magasin supprimé avec succès');
    }
}
