<?php

namespace App\Livewire\Admin;

use App\Models\Shop;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Attributes\On;
use Livewire\Component;
use Livewire\Attributes\Url;
use Livewire\WithPagination;

class UsersComponent extends Component
{
    use WithPagination;
    use LivewireAlert;
    #[Url]
    public $search = '';
    public $isModalOpen = false;
    public $userItem = null;
    public $userIdToDelete = null;
    public $password, $password_confirmation;
    protected $rules = [
        'userItem.name' => 'required|string|min:3|max:255',
        'userItem.email' => 'required|string|max:255',
        'userItem.role' => 'required|string|max:255',
        'userItem.shop_id' => 'required_if:userItem.role,employee,owner|string|max:255',
        'password' => 'nullable|string|min:8|confirmed',
    ];
  
    public function render()
    {
        return view('livewire.admin.users-component', [
            'items' => User::with('shop')->where('name', 'like', '%'.$this->search.'%')->paginate(10),
            'shops' => Shop::all(),
        ]);
    }
    public function openModal($userId = null)
    {
        $this->userItem = User::find($userId);
        if (!$this->userItem) {
            $this->userItem = new User();
        }
        $this->isModalOpen = true;
    }
    public function save()
    {
        if($this->userItem->email == Auth::user()->email){
            $this->alert('error', 'Vous ne pouvez pas modifier votre propre email');
            return;
        }
        if (User::where('email', $this->userItem->email)
            ->where('id', '!=', $this->userItem->id)
            ->exists()) {
            $this->alert('error', 'Cet login est déjà utilisé');
            return;
        }
        $this->validate();
        if ($this->password) {
            $this->userItem->password = Hash::make($this->password);
        }
        $this->userItem->save();
        $this->isModalOpen = false;
        $this->reset();
        $this->alert('success', 'Utilisateur ajouté avec succès');
    }
    public function delete($userId)
    {
        $this->userIdToDelete = $userId;
        $this->confirm('Voulez-vous vraiment supprimer cet utilisateur ?', [
            'onConfirmed' => 'confirmed',

        ]);
    }
    #[On('confirmed')]
    public function confirmDelete()
    {
        $user = User::find($this->userIdToDelete);
        $user->deleted_by = Auth::user()->id;
        $user->delete();
        $this->reset('userIdToDelete');
        $this->alert('success', 'Utilisateur supprimé avec succès');
    }
}
