<?php

namespace App\Livewire\Forms;

use App\Models\Categorie;
use App\Models\Product;
use Livewire\Component;
use Livewire\Attributes\On;
use Livewire\WithFileUploads;
use Illuminate\Support\Str;

class ProductSelect extends Component
{
    use WithFileUploads;
    public $search, $selected_name;
    public $model;
    public $isVisible = false;
    public $showFormAddProduct = false;
    public $newProductItem;
    public $categories;
    protected $rules = [
        'newProductItem.name' => 'required|string|min:3|max:255',
        'newProductItem.categorie_id' => 'required|exists:categories,id',
        'newProductItem.price' => 'required|numeric|min:0',
        'newProductItem.seuil_stock' => 'required|integer|min:0',
        'newProductItem.image' => 'nullable|image|max:1024|mimes:png,jpg,jpeg,gif,webp',
    ];
  
    public function render()
    {
        return view('livewire.forms.product-select', 
        ['products' => 
            Product::select('id', 'name', 'image')->where('name', 'like','%'.$this->search.'%')->limit(10)->get()
        ]);
    }
    public function mount(){
        $this->categories = Categorie::all();
    }
    public function addNewProduct(){
        $this->showFormAddProduct = true;
        $this->newProductItem = new Product();
        $this->newProductItem->seuil_stock = 10;
        $this->newProductItem->name  = $this->search;
    }
    public function saveNewProduct(){
        $validated  =  $this->validate();

        $this->newProductItem->fill($validated['newProductItem']);
        if ($validated['newProductItem']['image']) {
            $this->newProductItem->image = $validated['newProductItem']['image']->store('products', 'public');
        }

        $this->newProductItem->slug = Str::slug($this->newProductItem->name);
        
        $this->newProductItem->shop_id = auth()->user()->shop->id;
        $this->newProductItem->save();
        $this->showFormAddProduct = false;
        $this->search = $this->newProductItem->name;
        $tosend = [
            'id' => $this->newProductItem->id,
            'name' => $this->newProductItem->name,
            'image' => $this->newProductItem->image,
        ];
        $this->sendValue($tosend);
    }
    #[On('')] 
    public function clearInput()
    {
        $this->search = null;
        $this->selected_name = null;
    }
    protected $listeners = [
        'clear-product-select' => 'clearInput'
    ];
    
    public function sendValue($product=null){
        if(empty($product)){
            $product = [
                'id' => "00000000",
                'name' => 'Nouveau produit',
                'image' => null,
            ];
        }
        $this->dispatch('update-data', data: $product);
        $this->search = $product["name"];
        $this->selected_name = $product["name"];
        $this->isVisible = false;
    }
}
