<?php

namespace App\Livewire\Owner;

use App\Models\Categorie;
use Illuminate\Support\Facades\Auth;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Attributes\On;
use Livewire\Component;
use Livewire\Attributes\Url;
use Livewire\WithPagination;
use Illuminate\Support\Str;
class CategoriesComponent extends Component
{
    use WithPagination;
    use LivewireAlert;
    #[Url]
    public $search = '';
    public $isModalOpen = false;
    public $categoryItem = null;
    public $categoryIdToDelete = null;
    protected $rules = [
        'categoryItem.name' => 'required|string|min:3|max:255',
        'categoryItem.description' => 'nullable|string|max:255',
        'categoryItem.parent_id' => 'nullable|exists:categories,id',

    ];
  
    public function render()
    {
        return view('livewire.owner.categories-component', [
            'items' => Categorie::with('parent')->where('name', 'like', '%'.$this->search.'%')->orderByDesc('created_at')->paginate(10),
        ]);
    }
    public function openModal($categoryId = null)
    {
        $this->categoryItem = Categorie::find($categoryId);
        if (!$this->categoryItem) {
            $this->categoryItem = new Categorie();
        }
        $this->isModalOpen = true;
    }
    public function save()
    {
        $data = $this->validate();
        $this->categoryItem->slug = Str::slug($this->categoryItem->name);
        $this->categoryItem->fill($data['categoryItem']);
        $this->categoryItem->shop_id = Auth::user()->shop_id;
        $this->categoryItem->save();
        $this->isModalOpen = false;
        $this->reset();
        $this->alert('success', 'Catégorie enregistrée avec succès');
    }
    public function delete($categoryId)
    {
        $this->categoryIdToDelete = $categoryId;
        $this->confirm('Voulez-vous vraiment supprimer cette catégorie ?', [
            'onConfirmed' => 'confirmed',
        ]);
    }
    #[On('confirmed')]
    public function confirmDelete()
    {
        $category = Categorie::find($this->categoryIdToDelete);
        $category->deleted_by = Auth::user()->id;
        $category->delete();
        $this->reset('categoryIdToDelete');
        $this->alert('success', 'Catégorie supprimée avec succès');
    }
}
