<?php

namespace App\Livewire\Owner;

use App\Models\Sale;
use Illuminate\Support\Facades\DB;
use Livewire\Component;

class CreancesComponent extends Component
{
    public $saleToSolde = null;
    public $isModalOpen = false;
    public $paiement_amount = 0;
    public $reste_a_payer = 0;
    public $mode_paiement_selected = null;
    public $modes_paiement = [[ 'name' => 'Cash', 'image' => 'cash.png' ],
    [ 'name' => 'Wave', 'image' => 'wave.png' ],[ 'name' => 'Orange Money', 'image' => 'orange-money.png' ],
    [ 'name' => 'Cheque', 'image' => 'cheque.png' ],[ 'name' => 'Virement', 'image' => 'virement.png' ],
    [ 'name' => 'Autre', 'image' => 'other.png' ] ];
    public function render()
    {
        $query = Sale::with(['paiements'])->withSum('paiements', 'amount')
        ->where('total_with_tax','>',0)
        ->where(function ($query) {
            $query->whereDoesntHave('paiements') // Factures sans aucun paiement
                  ->orWhereHas('paiements', function ($subQuery) {
                      $subQuery->select(DB::raw('SUM(amount)'))
                          ->groupBy('sale_id')
                          ->havingRaw('SUM(amount) < (SELECT total_with_tax FROM sales WHERE sales.id = paiements.sale_id)');
                  });
        });
        return view('livewire.owner.creances-component',
        [
            'creances' => $query->get()
        ]
    );
    }

    public function showCreanceModal($saleId)
    {
        $this->saleToSolde = Sale::withSum('paiements', 'amount')->find($saleId);
        $this->isModalOpen = true;
        $this->paiement_amount = $this->saleToSolde->total_with_tax - $this->saleToSolde->paiements_sum_amount;
        $this->reste_a_payer = $this->saleToSolde->total_with_tax - $this->saleToSolde->paiements_sum_amount;
    }
    public function savePaiement()
    {
        if($this->paiement_amount > $this->reste_a_payer){
            $this->addError('paiement_amount', 'Le montant encaissé ne peut pas être supérieur au reste à payer');
            return;
        }
        $this->validate([
            'paiement_amount' => 'required|numeric|min:0',
            'mode_paiement_selected' => 'required',
        ]);
        $this->saleToSolde->paiements()->create([
            'amount' => $this->paiement_amount,
            'payment_mode' => $this->mode_paiement_selected,
        ]);
        $this->isModalOpen = false;
    }
}
