<?php

namespace App\Livewire\Owner;

use App\Models\Product;
use App\Models\Categorie;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Attributes\On;
use Livewire\Component;
use Livewire\Attributes\Url;
use Livewire\Features\SupportFileUploads\WithFileUploads;
use Livewire\WithPagination;
use Illuminate\Support\Str;

class ProductsComponent extends Component
{
    use WithPagination;
    use LivewireAlert;
    use WithFileUploads;
    #[Url]
    public $search = '';
    public $isModalOpen = false;
    public $productItem = null;
    public $productIdToDelete = null;
    public $editMode = false;
    public $productImage = null;
    public $productImages = [];
    protected $rules = [
        'productItem.name' => 'required|string|min:3|max:255',
        
        'productItem.categorie_id' => 'required|exists:categories,id',
        'productItem.price' => 'required|numeric|min:0',
        'productItem.stock' => 'required|integer|min:0',
        'productItem.seuil_stock' => 'required|integer|min:0',
        'productImage' => 'nullable|image|max:1024|mimes:png,jpg,jpeg,gif,webp',
        'productImages' => 'nullable|array|max:10',
        'productImages.*' => 'nullable|image|max:1024|mimes:png,jpg,jpeg,gif,webp',
    ];
  
    public function render()
    {
        $items = Product::with('categorie')->withSum('supplyItems', 'stock')
                ->where('name', 'like', '%'.$this->search.'%')
                ->where('shop_id', Auth::user()->shop_id)
                ->paginate(10);

        return view('livewire.owner.products-component', [
            'items' => Product::with('categorie')->withSum('supplyItems', 'stock')
                ->where('name', 'like', '%'.$this->search.'%')
                ->where('shop_id', Auth::user()->shop_id)
                ->paginate(10),
            'categories' => Categorie::where('shop_id', Auth::user()->shop_id)->orWhereNull('shop_id')->get()
        ]);
    }

    public function openModal($productId = null)
    {
        $this->productItem = Product::find($productId);
        if (!$this->productItem) {
            $this->productItem = new Product();
            $this->editMode = false;
        } else {
            $this->editMode = true;
            $this->productItem->images = $this->productItem->images()->get();
           // dd($this->productItem->images);
           
        }
        $this->isModalOpen = true;
    }

    public function save()
    {
        
        $validated = $this->validate();
        $images = [];
        $this->productItem->fill($validated['productItem']);
        if ($validated['productImage']) {
            $this->productItem->image = $validated['productImage']->store('products', 'public');
        }
        if ($validated['productImages']) {
            foreach ($validated['productImages'] as $image) {
                $images[] = $image->store('products', 'public');
            }
        }
        $this->productItem->shop_id = Auth::user()->shop_id;
        $this->productItem->slug = Str::slug($this->productItem->name);
        $this->productItem->save();
        foreach ($images as $image) {
            $this->productItem->images()->create(['image' => $image]);
        }
        $this->isModalOpen = false;
        $this->reset();
        $this->alert('success', 'Produit enregistré avec succès');
    }

    public function delete($productId)
    {
        $this->productIdToDelete = $productId;
        $this->confirm('Voulez-vous vraiment supprimer ce produit ?', [
            'onConfirmed' => 'confirmed',
        ]);
    }

    #[On('confirmed')]
    public function confirmDelete()
    {
        $product = Product::find($this->productIdToDelete);
        $product->deleted_by = Auth::user()->id;
        $product->delete();
        $this->reset('productIdToDelete');
        $this->alert('success', 'Produit supprimé avec succès');
    }
}
