<?php

namespace App\Livewire\Owner;

use App\Models\Supplier;
use Illuminate\Support\Facades\Auth;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Attributes\On;
use Livewire\Component;
use Livewire\Attributes\Url;
use Livewire\WithPagination;

class SuppliersComponent extends Component
{
    use WithPagination;
    use LivewireAlert;
    #[Url]
    public $search = '';
    public $isModalOpen = false;
    public $supplyItem = null;
    public $supplyIdToDelete = null;
    protected $rules = [
        'supplyItem.name' => 'required|string|min:3|max:255',
        'supplyItem.phone' => 'nullable|string|max:20',
    ];
  
    public function render()
    {
        return view('livewire.owner.suppliers-component', [
            'items' => Supplier::where('name', 'like', '%'.$this->search.'%')->paginate(10),
        ]);
    }

    public function openModal($supplyId = null)
    {
        $this->supplyItem = Supplier::find($supplyId);
        if (!$this->supplyItem) {
            $this->supplyItem = new Supplier();
        }
        $this->isModalOpen = true;
    }

    public function save()
    {
        $data = $this->validate();
        
        $this->supplyItem->fill($data['supplyItem']);
        $this->supplyItem->shop_id = Auth::user()->shop_id;
        $this->supplyItem->save();
        $this->isModalOpen = false;
        $this->reset();
        $this->alert('success', 'Fournisseur enregistré avec succès');
    }

    public function delete($supplyId)
    {
        $this->supplyIdToDelete = $supplyId;
        $this->confirm('Voulez-vous vraiment supprimer ce fournisseur ?', [
            'onConfirmed' => 'confirmed',
        ]);
    }

    #[On('confirmed')]
    public function confirmDelete()
    {
        $supply = Supplier::find($this->supplyIdToDelete);
        $supply->deleted_by = Auth::user()->id;
        $supply->delete();
        $this->reset('supplyIdToDelete');
        $this->alert('success', 'Fournisseur supprimé avec succès');
    }
}
