<?php

namespace App\Livewire\Owner;

use App\Models\Shop;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Jantinnerezo\LivewireAlert\LivewireAlert;
use Livewire\Attributes\On;
use Livewire\Component;
use Livewire\Attributes\Url;
use Livewire\WithPagination;

class UsersComponent extends Component
{
    use WithPagination;
    use LivewireAlert;
    #[Url]
    public $search = '';
    public $isModalOpen = false;
    public $userItem = null;
    public $userIdToDelete = null;
    public $password, $password_confirmation;
    protected $rules = [
        'userItem.name' => 'required|string|min:3|max:255',
        'userItem.email' => 'required|string|max:255',
        'userItem.role' => 'required|string|max:255|in:employee,owner',
        'password' => 'nullable|string|min:8|confirmed',
    ];
  
    public function render()
    {
        return view('livewire.owner.users-component', [
            'items' => User::where('name', 'like', '%'.$this->search.'%')->where('shop_id', Auth::user()->shop_id)->where('id', '!=', Auth::user()->id)->paginate(10),
            'shops' => Shop::all(),
        ]);
    }
    public function openModal($userId = null)
    {
        $this->userItem = User::find($userId);
        if (!$this->userItem) {
            $this->userItem = new User();
        }
        $this->isModalOpen = true;
    }
    public function save()
    {
        $this->userItem->shop_id = Auth::user()->shop_id;
        $validatedData = $this->validate();
        if ($this->password) {
            $validatedData['userItem']['password'] = Hash::make($this->password);
        }
        $this->userItem->fill($validatedData['userItem']);
        //dd($this->userItem);
        $this->userItem->save();
        $this->isModalOpen = false;
        $this->reset();
        $this->alert('success', 'Utilisateur ajouté avec succès');
    }
    public function delete($userId)
    {
        $this->userIdToDelete = $userId;
        $this->confirm('Voulez-vous vraiment supprimer cet utilisateur ?', [
            'onConfirmed' => 'confirmed',
        ]);
    }
    #[On('confirmed')]
    public function confirmDelete()
    {
        $user = User::find($this->userIdToDelete);
        $user->deleted_by = Auth::user()->id;
        $user->delete();
        $this->reset('userIdToDelete');
        $this->alert('success', 'Utilisateur supprimé avec succès');
    }
}
