<div>
    <!-- Heading -->
    
   
   <!-- Card -->
   <div class="bg-white rounded-xl shadow p-6 dark:bg-dark2">
       
       <!-- Search and Add button -->
       <div class="page__heading ">
           <h1 class="w-full">Liste des produits</h1>
       </div>
       <div class="flex items-center justify-between mb-6">
           
           <div class="flex-1 mr-4 max-w-md relative">
               <x-lucide-search class="absolute inset-y-0 left-0 flex items-center pl-3 w-8 h-full text-gray-500"/>
   
               <input type="text" wire:model.live="search" class="w-full !pl-[3rem] pr-10 p-2 border rounded-md focus:outline-none focus:border-blue-500" placeholder="Rechercher un produit...">
               @if($search)
               <button wire:click="$set('search', '')" class="absolute inset-y-0 right-0 flex items-center pr-3">
                   <x-lucide-circle-x class="text-xl inset-y-0 left-0 flex items-center pl-3 w-8 h-full text-gray-500"/>
               </button>
               @endif
           </div>
           <button class="button bg-blue-600 text-white flex items-center gap-2" wire:click="openModal()">
               <x-lucide-circle-plus class="text-xl inset-y-0 left-0 flex items-center w-5 h-5 h-full"/>
               <span class="hidden md:block">
                    Ajouter un produit
                </span>
           </button>
       </div>
   
       <!-- Table -->
       <div class="grid grid-cols-1 md:grid-cols-4 gap-4">
           @foreach($items as $item)
           <div class="bg-white rounded-lg shadow-lg overflow-hidden hover:shadow-xl transition-shadow">
               <div class="flex">
                   <!-- Image section - Left -->
                   <div class="w-1/3 relative">
                       @if($item->image)
                           <img src="{{ asset('storage/' . $item->image) }}" alt="{{ $item->name }}" class="w-full h-full object-cover">
                       @else
                           <div class="w-full h-full bg-gray-200 flex items-center justify-center">
                               <x-lucide-image class="w-12 h-12 text-gray-400"/>
                           </div>
                       @endif
                       <div class="absolute top-2 right-2">
                           <span class="bg-white px-3 py-1 rounded-full font-bold text-xs text-blue-600 shadow">{{ number_format($item->price, 0, ',', '.') }} F</span>
                       </div>
                   </div>

                   <!-- Content section - Right -->
                   <div class="w-2/3 p-4">
                       <div class="mb-3">
                           <h3 class="font-semibold text-lg text-gray-800">{{ $item->name }}</h3>
                           <p class="text-sm text-gray-600">{{ $item->categorie->name }}</p>
                       </div>

                       <div class="space-y-2">
                           <div class="flex justify-between text-sm">
                               <span class="text-gray-600">Stock:</span>
                               <span class="font-medium {{ $item->supply_items_sum_stock <= $item->seuil_stock ? 'text-red-600' : 'text-green-600' }}">
                                   {{ $item->supply_items_sum_stock }}
                               </span>
                           </div>
                           <div class="flex justify-between text-sm">
                               <span class="text-gray-600">Seuil de stock:</span>
                               <span class="font-medium">{{ $item->seuil_stock }}</span>
                           </div>
                       </div>
                   </div>
               </div>

               <!-- Buttons section - Bottom -->
               <div class="flex items-center gap-2 p-4 border-t">
                   <button class="flex-1 flex items-center justify-center gap-1 rounded-md bg-blue-600 px-3 py-1.5 text-white text-sm hover:bg-blue-700 transition-colors" wire:click="openModal({{ $item->id }})">
                       <x-lucide-edit class="h-4 w-4"/> Modifier
                   </button>
                   <button class="flex-1 flex items-center justify-center gap-1 rounded-md bg-red-600 px-3 py-1.5 text-white text-sm hover:bg-red-700 transition-colors" wire:click="delete({{ $item->id }})">
                       <x-lucide-trash class="h-4 w-4"/> Supprimer
                   </button>
               </div>
           </div>
           @endforeach
       </div>
   </div>
   <div class="lg:p-20 p-10 uk-modal {{ $isModalOpen ? 'uk-open' : '' }}" id="scrolling" uk-modal="" style="overscroll-behavior: contain; display: block;" tabindex="-1">
                                       
       <div class="absolute bottom-0 right-0 mx-auto bg-white border-l-4 border-slate-200  shadow-4xl uk-modal-dialog lg:w-[700px] w-[300px] min-h-screen">
   
           <div class="px-4 py-3 border-b">
               <h2 class="text-xl font-semibold">
                @if($editMode)
                    Modifier un produit
                @else
                    Ajouter un produit
                @endif
               </h2>
           </div>
           
          <form action="" wire:submit.prevent="save">
           <div class="p-6 uk-overflow-auto" uk-overflow-auto="" style=" overscroll-behavior: contain;">
               <div class="mb-4">
                   <x-label for="name" :value="__('Nom du produit')" />
                   <x-input id="name" class="block mt-1 w-full" wire:model.live="productItem.name" type="text" required autofocus />
                   <x-input-error for="productItem.name" class="mt-2" />
               </div>
               <div class="mb-4">
                   <x-label for="price" :value="__('Prix')" />
                   <x-input id="price" class="block mt-1 w-full" wire:model.live="productItem.price" type="number" step="0.01" required />
                   <x-input-error for="productItem.price" class="mt-2" />
               </div>
               <div class="mb-4">
                   <x-label for="categorie_id" :value="__('Catégorie')" />
                   <flux:select variant="listbox" searchable wire:model.live="productItem.categorie_id" indicator="checkbox" required> 
                    <x-slot name="search">
                        <flux:select.search class="px-4" placeholder="Rechercher une catégorie..." />
                    </x-slot>
                    @foreach($categories as $category)
                    <flux:option value="{{ $category->id }}">{{ $category->name }}</flux:option>
                    @endforeach
                </flux:select>
                   <x-input-error for="productItem.categorie_id" class="mt-2" />
                </div>
                <div class="mb-4 flex items-end gap-2">
                    <div class="mr-2"> 
                        <flux:input type="file" wire:click="$set('productImage', null)" wire:model="productImage" label="Image phare du produit" accept="image/png, image/gif, image/jpeg, image/webp, image/jpg"/>
                        <x-input-error for="productImage" class="mt-2" />
                    </div>
                    <div>
                       @if(isset($productItem->image))
                       <img src="{{ ($editMode && isset($productImage)) ? $productImage->temporaryUrl() : 'storage/'.$productItem->image }}" alt="Image phare du produit" class="w-12 h-12 rounded-md">
                       @endif
                       
                    </div>
                </div>

                
               <flux:separator text="Informations supplémentaires" />
               <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                
                
                <div class="mb-4">
                    <x-label for="stock" :value="__('Stock actuel')" />
                    <x-input id="stock" class="block mt-1 w-full" wire:model.live="productItem.stock" type="number" required />
                    <x-input-error for="productItem.stock" class="mt-2" />
                </div>
                <div class="mb-4">
                    <x-label for="seuil_stock" :value="__('Seuil de stock à alerter')" />
                    <x-input id="seuil_stock" class="block mt-1 w-full" wire:model.live="productItem.seuil_stock" type="number" required />
                    <x-input-error for="productItem.seuil_stock" class="mt-2" />
                </div>
                

               </div>
           </div>
           <div class="flex justify-end gap-2 p-6 text-sm font-medium px-4 py-3 border-t absolute bottom-0 w-full">
               <button class="px-4 py-1.5 bg-red-600 hover:bg-red-500 text-white rounded-md uk-modal-close" type="button">Annuler</button>
               <button class="px-5 py-1.5 bg-blue-600 hover:bg-blue-900 text-white rounded-md " type="submit">Enregistrer</button>
           </div>
          </form>
   
           <!-- close button -->
           <button type="button" class="bg-white rounded-full p-2 absolute right-0 top-0 m-3 dark:bg-slate-600 " wire:click="$set('isModalOpen', false)">
               <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-6 h-6">
                   <path stroke-linecap="round" stroke-linejoin="round" d="M6 18L18 6M6 6l12 12"></path>
               </svg>
           </button>
       
       </div>
   
   </div>
   
       
   </div>