<div>
    <!-- Heading -->
    
    <!-- Card -->
    <div class="bg-white rounded-xl shadow p-6 dark:bg-dark2">
        
        <!-- Search and Add button -->
        <div class="page__heading">
            <h1 class="w-full">Approvisionnements</h1>
        </div>
        <div class="flex items-center justify-between mb-6">
            
            <div class="flex-1 mr-4 max-w-md relative">
                <x-lucide-search class="absolute inset-y-0 left-0 flex items-center pl-3 w-8 h-full text-gray-500"/>
    
                <input type="text" wire:model.live="search" class="w-full !pl-[3rem] pr-10 p-2 border rounded-md focus:outline-none focus:border-blue-500" placeholder="Rechercher un approvisionnement...">
                @if($search)
                <button wire:click="$set('search', '')" class="absolute inset-y-0 right-0 flex items-center pr-3">
                    <x-lucide-circle-x class="text-xl inset-y-0 left-0 flex items-center pl-3 w-8 h-full text-gray-500"/>
                </button>
                @endif
            </div>
            <button class="button bg-blue-600 text-white flex items-center gap-2" wire:click="openModal()">
                <x-lucide-circle-plus class="text-xl inset-y-0 left-0 flex items-center w-5 h-5 h-full"/>
                <span class="hidden md:block">
                    Nouvel approvisionnement
                </span>
            </button>
        </div>
    
        <!-- Table -->
        <div class="overflow-x-auto">
            <table class="min-w-full divide-y divide-gray-200 dark:divide-gray-700">
                <thead>
                    <tr>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">N° Commande</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Fournisseur</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Date</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Montant</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Statut</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                    </tr>
                </thead>
                <tbody class="bg-white divide-y divide-gray-200 dark:divide-gray-700">
                    @foreach($items as $item)
                    <tr class="odd:bg-white odd:dark:bg-gray-900 even:bg-gray-50 even:dark:bg-gray-800 hover:bg-gray-100 hover:dark:bg-gray-700">
                        <td class="px-4 py-3 whitespace-nowrap">{{ $item->order_number }}</td>
                        <td class="px-4 py-3 whitespace-nowrap text-center">{{ $item->supplier->name }}</td>
                        <td class="px-4 py-3 whitespace-nowrap text-center">{{ $item->order_date }}</td>
                        <td class="px-4 py-3 whitespace-nowrap text-center">{{ number_format($item->total_amount, 0, ',', ' ') }} </td>
                        <td class="px-4 py-3 whitespace-nowrap text-center">
                            <span class="px-2 py-1 rounded-full text-xs
                                @if($item->status === 'pending') bg-yellow-100 text-yellow-800
                                @elseif($item->status === 'delivered') bg-green-100 text-green-800
                                @else bg-red-100 text-red-800
                                @endif">
                                {{ $item->status }}
                            </span>
                        </td>
                        <td class="px-4 py-3 whitespace-nowrap">
                            <div class="flex items-center gap-2">
                                

                                <button class="flex items-center gap-2 rounded-md bg-red-600 px-2 py-1 text-white" wire:click="delete({{ $item->id }})">
                                    <x-lucide-trash class="h-4"/> Supprimer
                                </button>
                            </div>
                        </td>
                    </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
    </div>

    <div class="lg:p-20 p-10 uk-modal {{ $isModalOpen ? 'uk-open' : '' }}" id="scrolling" uk-modal="" style="overscroll-behavior: contain; display: block;" tabindex="-1">
        <div class="absolute bottom-0 right-0 mx-auto bg-white border-l-4 border-slate-200 shadow-4xl uk-modal-dialog lg:w-[700px] md:w-[500px] w-[100%] min-h-screen">
            <div class="px-4 py-3 border-b">
                <h2 class="text-xl font-semibold">Nouvel approvisionnement</h2>
            </div>
            
            <form wire:submit.prevent="save">
                <div class="p-6 uk-overflow-auto" x-data="{ step: $wire.entangle('step') }" uk-overflow-auto="" style="overscroll-behavior: contain;">
                    <div class="flex items-center justify-center mb-8">
                        <div class="flex items-center">
                            <div class="cursor-pointer h-8 rounded-md flex items-center justify-center px-2 {{$step >= 1 ? 'bg-blue-600 text-white' : 'bg-gray-200'}}" wire:click="$set('step', 1)">Etape 1</div>
                            <div class="h-1 w-12 {{$step > 1 ? 'bg-blue-600' : 'bg-gray-200'}}"></div>
                            <div class="cursor-pointer h-8 rounded-md flex items-center justify-center px-2 {{$step >= 2 ? 'bg-blue-600 text-white' : 'bg-gray-200'}}" wire:click="$set('step', 2)">Etape 2 </div>
                            <div class="h-1 w-12 {{$step > 2 ? 'bg-blue-600' : 'bg-gray-200'}}"></div>
                            <div class="cursor-pointer h-8 rounded-md flex items-center justify-center px-2 {{$step == 3 ? 'bg-blue-600 text-white' : 'bg-gray-200'}}" wire:click="$set('step', 3)">Etape 3</div>
                        </div>
                    </div>
                    <!-- Step 1: Informations de base -->
                    <div class="mb-6" x-show="step === 1">
                        <h3 class="font-semibold mb-4">Étape 1: Informations de base</h3>
                        
                        <div class="mb-4">
                            <x-label for="supplier" :value="__('Fournisseur')" />
                            <select id="supplier" class="block mt-1 w-full border-gray-300 focus:border-indigo-500 focus:ring-indigo-500 rounded-md shadow-sm" wire:model.live="supplyItem.supplier_id" required>
                                <option value="">Sélectionner un fournisseur</option>
                                @foreach($suppliers as $supplier)
                                    <option value="{{ $supplier->id }}">{{ $supplier->name }}</option>
                                @endforeach
                                <option value="0">Nouveau fournisseur</option>
                            </select>
                            <x-input-error for="supplyItem.supplier_id" class="mt-2" />
                        </div>
                        @if (isset($supplyItem->supplier_id) && $supplyItem->supplier_id ===  "0")
                            <div class="mb-4">
                                <x-label for="supplier_name" :value="__('Nom du fournisseur')" />
                                <x-input id="supplier_name" class="block mt-1 w-full" wire:model.live="new_supplier_name" required />
                                <x-input-error for="new_supplier_name" class="mt-2" />
                            </div>
                            <div class="mb-4">
                                <x-label for="supplier_phone" :value="__('Téléphone')" />
                                <x-input id="supplier_phone" class="block mt-1 w-full" wire:model.live="new_supplier_phone" required />
                                <x-input-error for="new_supplier_phone" class="mt-2" />
                            </div>
                        @endif

                        <div class="mb-4">
                            <x-label for="order_date" :value="__('Date de commande')" />
                            <x-input id="order_date" class="block mt-1 w-full" type="date" wire:model.live="supplyItem.order_date" required />
                            <x-input-error for="supplyItem.order_date" class="mt-2" />
                        </div>

                        {{-- <div class="mb-4 ">
                            <x-label for="status" :value="__('Statut')" />
                            <select id="status"  class="block mt-1 w-full border-gray-300 focus:border-indigo-500 focus:ring-indigo-500 rounded-md shadow-sm" wire:model.live="supplyItem.status">
                                <option value="pending">En attente</option>
                                <option value="delivered" selected>Livré</option>
                                <option value="cancelled">Annulé</option>
                            </select>
                            <x-input-error for="supplyItem.status" class="mt-2" />
                        </div> --}}
                    </div>

                    <!-- Step 2: Produits -->
                    <div class="mb-6" x-show="step === 2">
                        <h3 class="font-semibold mb-4">Étape 2: Sélection des produits</h3>
                        
                        <div class="mb-4">
                            <table class="min-w-full divide-y divide-gray-200 dark:divide-gray-700">
                                <thead>
                                    <tr>
                                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Produit</th>
                                        <th>Quantité</th>
                                        <th>Prix</th>
                                        <th>Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach($supplyItems as $index => $item)
                                    <tr>
                                        <td class="px-1 py-3 ">{{ $item['product_name'] }}</td>
                                        <td class="px-1 py-3 whitespace-nowrap text-center">
                                            <x-input type="number" class="w-12 lg:w-32 h-6 lg:h-12 text-sm px-1 lg:px-2" name="" id="" wire:model.live="supplyItems.{{ $index }}.quantity" />
                                        </td>
                                        <td class="px-1 py-3 whitespace-nowrap text-center">
                                            <x-input type="number" class="w-24 lg:w-32 h-6 lg:h-12 text-sm px-1 lg:px-2" name="" id="" wire:model.live="supplyItems.{{ $index }}.price" />
                                        </td>
                                        <td class="px-1 py-3 whitespace-nowrap text-center">
                                            <button type="button" class="text-red-600" wire:click="removeItem({{ $index }})">
                                                <x-lucide-trash class="h-5 w-5"/>
                                            </button>
                                        </td>
                                    </tr>
                                    @endforeach
                                    <tr>
                                        <td class="px-4 py-3 whitespace-nowrap text-center" colspan="2">Total</td>
                                        <td class="px-4 py-3 whitespace-nowrap text-center font-bold" colspan="2">{{ $total_amount }}</td>
                                    </tr>
                                </tbody>
                            </table>
                            <div>
                                
                            </div>
                            <p class="text-sm text-gray-500">
                                Si vous ne trouvez pas le produit que vous cherchez, vous pouvez en ajouter un nouveau.
                            </p>
                            <div class="flex flex-col lg:flex-row items-end gap-2 mt-4">
                                
                               <div class=" w-full  border-gray-300 focus:border-indigo-500 focus:ring-indigo-500 rounded-md shadow-sm">
                                    <label for="productItemToAdd" class="block text-sm font-medium text-gray-700">Produit</label>
                                    @livewire('forms.product-select', ['model' => 'productItemToAdd'])
                               </div>
                                <div class="flex w-full lg:w-3/4 items-center gap-2">
                                    <div class="w-1/3">
                                        <label for="quantityToAdd" class="block text-sm font-medium text-gray-700">Quantité</label>
                                        <x-input type="number" step="1" class=" w-full border-gray-300 focus:border-indigo-500 focus:ring-indigo-500 rounded-md shadow-sm" placeholder="Quantité" wire:model.live="quantityToAdd" />
                                    </div>
                                    <div class="w-2/3">
                                        <label for="priceToAdd" class="block text-sm font-medium text-gray-700">Prix d'achat unitaire</label>
                                        <x-input type="number" step="10" class=" w-full border-gray-300 focus:border-indigo-500 focus:ring-indigo-500 rounded-md shadow-sm" placeholder="Prix" wire:model.live="priceToAdd" />
                                    </div>
                                </div>
                                
                                <button type="button" class="mt-2 w-full lg:w-1/4 flex justify-center items-center gap-2 bg-blue-600 text-white px-2 py-3 rounded-md" wire:click="addItem">
                                    <x-lucide-plus class="h-5 w-5 "/>
                                    <span class="block md:hidden">Ajouter un produit</span>
                                </button>
                            </div>
                        </div>
                    </div>

                    <!-- Step 3: Récapitulatif -->
                    <div class="mb-6" x-show="step === 3">
                        <h3 class="font-semibold mb-4">Étape 3: Récapitulatif</h3>
                        
                        <div class="mb-4">
                            <div class="grid grid-cols-2 gap-4">
                                <div>
                                    <x-label :value="__('Fournisseur')" />
                                    <p class="mt-1">{{ $supplier_name ?? '' }}</p>
                                </div>
                                <div>
                                    <x-label :value="__('Date de commande')" />
                                    <p class="mt-1">{{ $order_date ?? '' }}</p>
                                </div>
                            </div>

                            <div class="mt-4">
                                <x-label :value="__('Produits commandés')" />
                                <div class="mt-2">
                                    @foreach($supplyItems as $item)
                                        <div class="flex justify-between py-1">
                                            <span>{{ $item['product_name'] }}</span>
                                            <span>{{ intval($item['quantity']) }} x {{ intval($item['price']) }} = {{ intval($item['quantity']) * intval($item['price']) }}</span>
                                        </div>
                                    @endforeach
                                </div>
                            </div>

                            <div class="mt-4">
                                <x-label for="total_amount" :value="__('Montant total')" />
                                <x-input id="total_amount" class="block mt-1 w-full" disabled type="number" step="0.01" wire:model.live="total_amount" required />
                            </div>
                        </div>
                    </div>

                    <!-- Navigation buttons -->
                    <div class="flex justify-between mt-6">
                        @if ($step > 1)
                        <button 
                            type="button" 
                            class="px-4 py-2 bg-gray-200 text-gray-700 rounded-md"
                            x-show="step > 1 "
                            wire:click="previousStep">
                            Précédent
                        </button>
                        @endif
                        @if ($step < 3)
                            <button 
                                type="button" 
                                class="px-4 py-2 bg-blue-600 text-white rounded-md ml-auto"
                                wire:click="nextStep">
                                Suivant
                        </button>
                        @endif
                        @if ($step == 3)
                            <button type="submit" class="px-4 py-2 bg-blue-600 text-white rounded-md ml-auto">
                                Enregistrer
                            </button>
                        @endif
                    </div>

                    <!-- Step indicator -->
                    
                </div>

                <div class="flex justify-end gap-2 p-6 text-sm font-medium px-4 py-3 border-t absolute bottom-0 w-full">
                    <button type="button" class="px-4 py-1.5 bg-red-600 hover:bg-red-500 text-white rounded-md" wire:click="$set('isModalOpen', false)">Fermer</button>
                </div>
            </form>

            <!-- close button -->
            <button type="button" class="bg-white rounded-full p-2 absolute right-0 top-0 m-3 dark:bg-slate-600" wire:click="$set('isModalOpen', false)">
                <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-6 h-6">
                    <path stroke-linecap="round" stroke-linejoin="round" d="M6 18L18 6M6 6l12 12"></path>
                </svg>
            </button>
        </div>
    </div>
</div>